==> homesitemaker-v0.4.2.tar.gz: homesitemaker/includes/languages/english/homesite-info.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//---------- ./homesite/info.php ----------

// Headline Row (HR)
$HR001="Last time edited: ";
$HR002="by";

// Info Botton
$IB001="Edit";
$IB002="Delete";

// Info Edition Messages (IEM)
$IEM001="Edition Date:";
$IEM002="Headline";
$IEM003="Text";
$TEXT008="If yo send it as HTML, then the tags will be parsed as HTML code";
$TEXT009="Send as:";
$TEXT010="Plain text";
$TEXT011="HTML";
$IEM005="This is the list with the current photos for current info.<br>".
        "You can select one or more to delete it.<br>Otherwise,".
        " if you wants to add a new image for this info, ".
        "then select it in the following Attach Photo box.";
$IEM006="Attach Photo:";

// Photo Table Editon Messages (PTEM)

$PTEM001="Delete";
$PTEM002="Filename";
$PTEM003="Id. Photo";
$PTEM004="Thumbnail";
 
// Info Edition Boton Messages (IEEBM)

$IEBM001="Preview";
$IEBM002="Publish"; // See homesite-includes-dbwa.pnp before translate this

// Info Deleting Messages (IDM)

$IDM001="Deleting Date:";
$IDM002="All the data will be lost and replaced with ".
        "the default one if you continue.<br><br>Be sure before continue !!!";
$IDM003="If you DOESN'T wants to show this secction anymore, ".
        "then you need to edit the config file.";

// Info Deleting Boton Messages (IDBM)

$IDBM001="Delete";

// Info Edition Alert Messages

$ALERT001="Empty section !<br>".
          "Maybe you want to add some information here.<br>".
          "Otherwise you should remove this section.";

?>

==> homesitemaker-v0.4.4.tar.gz: homesitemaker/includes/languages/english/homesite-info.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//---------- ./homesite/info.php ----------

// Headline Row (HR)
$HR001="Last time edited: ";
$HR002="by";

// Info Botton
$IB000="Edit (GUI)";
$IB001="Edit (text)";
$IB002="Delete";

// Info Edition Messages (IEM)
$IEM001="Edition Date:";
$IEM002="Headline";
$IEM003="Text";
$TEXT008="If yo send it as HTML, then the tags will be parsed as HTML code";
$TEXT009="Send as:";
$TEXT010="Plain text";
$TEXT011="HTML";
$TEXT012="If you don't see the edit toolbox, is due to your browser don't support this feature.<br>".
         "Please choose Edit (text) option or use one of the following browsers:<br>".
         "IE 5.5+ (Windows), Firefox 1.0+, Mozilla 1.3+ or Netscape 7+";
$IEM005="This is the list with the current photos for current info.<br>".
        "You can select one or more to delete it.<br>Otherwise,".
        " if you wants to add a new image for this info, ".
        "then select it in the following Attach Photo box.";
$IEM006="Attach Photo:";

// Photo Table Editon Messages (PTEM)

$PTEM001="Delete";
$PTEM002="Filename";
$PTEM003="Id. Photo";
$PTEM004="Thumbnail";
 
// Info Edition Boton Messages (IEEBM)

$IEBM001="Preview";
$IEBM002="Publish"; // See homesite-includes-dbwa.pnp before translate this

// Info Deleting Messages (IDM)

$IDM001="Deleting Date:";
$IDM002="All the data will be lost and replaced with ".
        "the default one if you continue.<br><br>Be sure before continue !!!";
$IDM003="If you DON'T want to show this secction anymore, ".
        "then you need to edit the config file.";

// Info Deleting Boton Messages (IDBM)

$IDBM001="Delete";

// Info Edition Alert Messages

$ALERT001="Empty section !<br>".
          "Maybe you want to add some information here.<br>".
          "Otherwise you should remove this section.";

?>
